@@ -57,11 +57,20 @@ def funcToParamDict(func, title=None, **overrides):
   from ._funcparse import funcToParamDict as _fpd
   return _fpd(func, title, **overrides)
 
-def mproc_apply(func, iterLst, descr='', iterArgPos=0,
-                extraArgs=(), showProgress=True, applyAsync=True,
-                total=None, pool=None,
-                debug=False,
-                **extraKwargs):
+def mproc_apply(
+    func, iterLst,
+    descr='',
+    iterArgPos=0,
+    extraArgs=(),
+    showProgress=True,
+    applyAsync=True,
+    total=None,
+    pool=None,
+    processes=None,
+    debug=False,
+    discardReturnValues=False,
+    **extraKwargs
+):
   if total is None:
     try:
       total = len(iterLst)
@@ -75,7 +84,7 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0,
       progBar.update()
     callback = updateProgBar
   elif showProgress:
-    iterLst = tqdm(iterLst, total=total)
+    iterLst = tqdm(iterLst, total=total, desc=descr)
 
   pre_results = []
   errs = {}
@@ -87,7 +96,7 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0,
       return func_(*args, **extraKwargs)
   else:
     if pool is None:
-      pool = mp.Pool()
+      pool = mp.Pool(processes)
     if applyAsync:
       def applyFunc(func_, args):
         return pool.apply_async(func_, args, kwds=extraKwargs,
@@ -107,6 +116,8 @@ def mproc_apply(func, iterLst, descr='', iterArgPos=0,
     for k, v in errs.items():
       msg += f'{k}: {v}\n'
     warn(msg)
+  if discardReturnValues:
+      return
   if applyAsync and not debug:
     return [res.get() for res in pre_results]
   else:
@@ -576,13 +587,55 @@ class ArgParseConverter(argparse.ArgumentParser):
   """Able to convert arguments to their types on parse_args"""
   convertRemainder = True
 
-  def parse_args(self, args=None, namespace=None):
-    def argConverter(arg):
-      try:
-        return ast.literal_eval(arg)
-      except:
-        return arg
+  @staticmethod
+  def argConverter(arg, returnSuccess=False):
+    try:
+      ret = ast.literal_eval(arg)
+      success = True
+    except:
+      ret = arg
+      success = False
+    if returnSuccess:
+      return ret, success
+    return ret
 
+  def _get_value(self, action, arg_string: str) -> t.Any:
+    ret, success = self.argConverter(arg_string, returnSuccess=True)
+    if not success:
+      return super()._get_value(action, arg_string)
+    return ret
+
+  @classmethod
+  def _lookAheadForValue(cls, extraIter, ii):
+    try:
+      nextK = extraIter[ii + 1]
+      if nextK.startswith('--'):
+        # This is also a flag condition, don't consume value this round
+        vv = True
+      else:
+        vv = cls.argConverter(nextK)
+        # Value consumed, move on an extra space
+        ii += 1
+    except IndexError:
+      vv = True
+    return vv, ii
+
+  @classmethod
+  def _consumeNextIterPos(cls, extraIter, ii):
+    item = extraIter[ii]
+    kk = vv = None
+    if not item.startswith('--'):
+      return kk, vv, ii+1
+    kk = item.strip('--')
+    if '=' in kk:
+      # Don't consume next key, this is the value
+      kk, toParse = kk.split('=', 1)
+      vv = cls.argConverter(toParse)
+    else:
+      vv, ii = cls._lookAheadForValue(extraIter, ii)
+    return kk, vv, ii+1
+
+  def parse_args(self, args=None, namespace=None):
     namespace, args = super().parse_known_args(args, namespace)
     # Treat remainder as if they belonged
     named = vars(namespace)
@@ -591,22 +644,9 @@ class ArgParseConverter(argparse.ArgumentParser):
     extraIter = list(args)
     ii = 0
     while ii < len(extraIter):
-      item = extraIter[ii]
-      if item.startswith('--'):
-        kk = item.strip('--')
-        try:
-          nextK = extraIter[ii + 1]
-          if nextK.startswith('--'):
-            # This is also a flag condition, don't consume value this round
-            vv = True
-          else:
-            vv = argConverter(nextK)
-            # Value consumed, move on an extra space
-            ii += 1
-        except IndexError:
-          vv = True
+      kk, vv, ii = self._consumeNextIterPos(extraIter, ii)
+      if kk is not None:
         named[kk] = vv
-        ii += 1
     return Namespace(**named)
 
 def makeCli(func: t.Callable, convertArgs=True, parserKwargs: dict=None, **procKwargs):
@@ -637,9 +677,11 @@ def makeCli(func: t.Callable, convertArgs=True, parserKwargs: dict=None, **procK
   for ch in funcDict['children']:
     if 'action' in ch['type']:
       continue
-    arg = parser.add_argument(f'--{ch["name"]}')
-    if ch['value'] is not RunOpts.PARAM_UNSET:
-      arg.type = type(ch['value'])
+    arg = parser.add_argument(f'--{ch["name"]}', required=ch['value'] is RunOpts.PARAM_UNSET)
+    if not arg.required:
+      chType = type(ch['value'])
+      if chType is not None:
+        arg.type = type(ch['value'])
       arg.default = ch['value']
     if 'tip' in ch:
       arg.help = tipConverter(ch['tip'])
@@ -869,6 +911,22 @@ def readDataFrameFiles(folder: FilePath,
   :param concatArgs: Dict of keywords passed to ``pd.concat``
   :param readArgs: Passed to readFunc for each encountered file
   """
-  files = Path(folder).glob(globExpr)
+  files = naturalSorted(Path(folder).glob(globExpr))
   dfs = [readFunc(file, **readKwargs) for file in files]
   return pd.concat(dfs, **(concatKwargs or {}))
+
+def naturalSorted(iterable):
+    """
+    Copied from tiffile implementation, but works with non-string objects (e.g. Paths)
+
+    >>> natural_sorted(['f1', 'f2', 'f10'])
+    ['f1', 'f2', 'f10']
+
+    """
+
+    def sortkey(x):
+        x = str(x)
+        return [(int(c) if c.isdigit() else c) for c in re.split(numbers, x)]
+
+    numbers = re.compile(r'(\d+)')
+    return sorted(iterable, key=sortkey)
