@@ -267,7 +267,7 @@ class ManualKeypoints(KeypointFinder):
     pg.mkQApp()
     children = []
     lbl = QtWidgets.QLabel('Select points (in order) on each image to register')
-    lbl.setAlignment(QtCore.Qt.AlignCenter)
+    lbl.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
     refPltItem = pg.PlotWidget()
     toWarpPltItem = pg.PlotWidget()
     children.append([refPltItem, toWarpPltItem])
