@@ -3,7 +3,7 @@ from __future__ import annotations
 import weakref
 from typing import Optional, Callable, Sequence
 
-from pyqtgraph.Qt import QtWidgets
+from pyqtgraph.Qt import QtWidgets, QtCore
 
 from . import parameditor as pe, ShortcutParameter
 from .prjparam import PrjParam
@@ -156,7 +156,7 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     if self.dock:
       self.dock.win = weakref.proxy(win)
 
-  def addToWindow(self, win: QtWidgets.QMainWindow, parentToolbarOrMenu=None):
+  def addMenuToWindow(self, win: QtWidgets.QMainWindow, parentToolbarOrMenu=None):
     if parentToolbarOrMenu is None:
       parentToolbarOrMenu = win.menuBar()
     if isinstance(parentToolbarOrMenu, QtWidgets.QToolBar):
@@ -170,6 +170,27 @@ class ParamEditorPlugin(pe.EditorPropsMixin):
     if self.menu is not None:
       parentToolbarOrMenu.addMenu(self.menu)
 
+  @staticmethod
+  def addDockToWindow(dock: QtWidgets.QDockWidget,
+                      win: QtWidgets.QMainWindow,
+                      dockArea: QtCore.Qt.DockWidgetArea=QtCore.Qt.DockWidgetArea.RightDockWidgetArea
+                      ):
+    curAreaWidgets = [d for d in win.findChildren(QtWidgets.QDockWidget)
+                      if win.dockWidgetArea(d) == dockArea]
+    try:
+      win.tabifyDockWidget(curAreaWidgets[-1], dock)
+    except IndexError:
+      # First dock in area
+      win.addDockWidget(dockArea, dock)
+
+  def addToWindow(self, win: QtWidgets.QMainWindow, parentToolbarOrMenu=None,
+                  dockArea: QtCore.Qt.DockWidgetArea=None):
+    if parentToolbarOrMenu is not None:
+      self.addMenuToWindow(win, parentToolbarOrMenu)
+    if dockArea is not None:
+      self.addDockToWindow(self.dock, win, dockArea)
+
+
 def dockPluginFactory(name_: str=None, editors: Sequence[pe.ParamEditor]=None):
   class DummyPlugin(ParamEditorPlugin):
     name = name_
