@@ -360,7 +360,7 @@ class AtomicProcess(ProcessStage):
     if wrapWith is not None:
       func = self._wrappedFunc(func, wrapWith)
     self.func = func
-    self.defaultInput = self.input.copy()
+    self.defaultInput = copy.deepcopy(self.input.copy())
 
   @classmethod
   def _wrappedFunc(cls, func, mainResultKeys: StrList):
@@ -488,7 +488,7 @@ class AtomicProcess(ProcessStage):
       # noinspection PyBroadException
       try:
         return (k in self.input.hyperParamKeys or k not in self.defaultInput) \
-              and (includeDefaults or v != self.defaultInput.get(k)) \
+              and (includeDefaults or not pg.eq(v, self.defaultInput.get(k))) \
               and v is not self.input.FROM_PREV_IO
       except Exception:
         return False
