@@ -466,7 +466,7 @@ class ButtonCollection(QtWidgets.QGroupBox):
 
 _layoutTypes = t.Union[t_e.Literal['H'], t_e.Literal['V']]
 class EasyWidget:
-  def __init__(self, children: t.List[t.Union[QtWidgets.QWidget, EasyWidget]],
+  def __init__(self, children: t.Sequence,
                layout: str=None, useSplitter=False, baseWidget: QtWidgets.QWidget=None):
     if baseWidget is None:
       baseWidget = QtWidgets.QWidget()
@@ -474,6 +474,7 @@ class EasyWidget:
     self.children_ = children
     self.useSplitter = None
     self.widget_ = baseWidget
+    self.layout_ = None
 
     self._resetOpts(useSplitter, layout)
 
@@ -543,6 +544,16 @@ class EasyWidget:
   def show(self):
     self.widget_.show()
 
+  def removeInnerMargins(self):
+    for ch in self.children_:
+      if isinstance(ch, EasyWidget):
+        ch.removeInnerMargins()
+        lay = ch.widget_.layout()
+        # layout_ != widget_.layout() for splitter
+        if lay:
+          lay.setContentsMargins(0, 0, 0, 0)
+          lay.setSpacing(0)
+
   @classmethod
   def listChildrenWrapper(cls, children: t.Union[t.Sequence, EasyWidget], maybeNewLayout: str=None):
     if not isinstance(children, EasyWidget):
@@ -562,6 +573,7 @@ class EasyWidget:
     win.easyChild = children
     win: HasEasyChild
     win.setCentralWidget(children.widget_)
+    children.removeInnerMargins()
     return win
 
   @classmethod
@@ -570,6 +582,7 @@ class EasyWidget:
     builder.build()
     retWidget: HasEasyChild = builder.widget_
     retWidget.easyChild = builder
+    builder.removeInnerMargins()
     return retWidget
 
   @classmethod
@@ -902,7 +915,7 @@ class MaskCompositor(ImageViewer):
       limits: [0,1]
       step: 0.1
     """
-    maskNames = np.array([s is not None for s in self.recordDf['scatter']])
+    maskNames = np.array([s is not None for s in self.recordDf['scatter']], dtype=bool)
     names = self.recordDf.index[maskNames]
     numMasks = len(names)
     cmap = cm.get_cmap(colormap, numMasks)
